@@ -20,7 +20,9 @@ var group__pw__client =
     ] ],
     [ "pw_client", "structpw__client.html", null ],
     [ "PW_TYPE_INTERFACE_Client", "group__pw__client.html#ga08028eb8b2bc7e721c22cd0683d0fd59", null ],
+    [ "PW_CLIENT_PERM_MASK", "group__pw__client.html#ga51150bec491ea25bc9f342db8d2cd908", null ],
     [ "PW_VERSION_CLIENT", "group__pw__client.html#gab23fc368d6d3c8dc6737af396c8ebdc4", null ],
+    [ "PW_API_CLIENT_IMPL", "group__pw__client.html#gaf5108ebbab011ebf414e629174f08d42", null ],
     [ "PW_ID_CLIENT", "group__pw__client.html#ga2effc0dcfd9a3dd90e72dde47f58fa62", null ],
     [ "PW_CLIENT_CHANGE_MASK_PROPS", "group__pw__client.html#gae4b0f81c2ec7e2249624a5f3bbe3db2d", null ],
     [ "PW_CLIENT_CHANGE_MASK_ALL", "group__pw__client.html#ga46fcb2a45cd729fd11659e81c4875339", null ],
@@ -35,13 +37,12 @@ var group__pw__client =
     [ "PW_CLIENT_METHOD_UPDATE_PERMISSIONS", "group__pw__client.html#ga44649b91990bb998e81a97c45fac4975", null ],
     [ "PW_CLIENT_METHOD_NUM", "group__pw__client.html#ga6ab68453545662580dfb9ef12eb99cc4", null ],
     [ "PW_VERSION_CLIENT_METHODS", "group__pw__client.html#gaca345ef08d2fe2316b793b2721489e7d", null ],
-    [ "pw_client_method", "group__pw__client.html#ga2e47a9955d2344ceeca575ddbfea546a", null ],
-    [ "pw_client_add_listener", "group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0", null ],
-    [ "pw_client_error", "group__pw__client.html#gaca741a1eb7d2306a1d06f7236bdcdd53", null ],
-    [ "pw_client_update_properties", "group__pw__client.html#ga376200cda9564550fda412c327cab29d", null ],
-    [ "pw_client_get_permissions", "group__pw__client.html#gad6b676ec28f1d8598d37c3b73a4f06b9", null ],
-    [ "pw_client_update_permissions", "group__pw__client.html#ga9429f541161b89136e87de99499d42d4", null ],
     [ "pw_client_info_update", "group__pw__client.html#ga534848e70aa11c5f41df3c8c9751c2bf", null ],
     [ "pw_client_info_merge", "group__pw__client.html#ga5aba78585d56fbbd77f87b7d841f633a", null ],
-    [ "pw_client_info_free", "group__pw__client.html#ga0052817a42d359a4b306d77717e2bec9", null ]
+    [ "pw_client_info_free", "group__pw__client.html#ga0052817a42d359a4b306d77717e2bec9", null ],
+    [ "pw_client_add_listener", "group__pw__client.html#ga2840c64fb485ce741d3784b7b018ab9c", null ],
+    [ "pw_client_error", "group__pw__client.html#gaf44224a6e8c6e3812c91eb8fb1fc4120", null ],
+    [ "pw_client_update_properties", "group__pw__client.html#gaa93b95f5357273c651e1d92509b819ca", null ],
+    [ "pw_client_get_permissions", "group__pw__client.html#gaea25d3b9f0a3c7366919abe35760bce7", null ],
+    [ "pw_client_update_permissions", "group__pw__client.html#ga8e92a1a610c3160343c32ae9f6ef23e5", null ]
 ];
\ No newline at end of file
