@@ -1,6 +1,6 @@
 var searchData=
 [
   ['key_0',['key',['../structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0',1,'spa_pod_prop::key'],['../structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a',1,'spa_dict_item::key']]],
-  ['key_20names_1',['key names',['../group__spa__keys.html',1,'Key Names'],['../group__pw__keys.html',1,'Key Names']]],
+  ['key_20names_1',['Key Names',['../group__spa__keys.html',1,'Key Names'],['../group__pw__keys.html',1,'Key Names']]],
   ['keys_2eh_2',['keys.h',['../spa_2include_2spa_2node_2keys_8h.html',1,'(Global Namespace)'],['../spa_2include_2spa_2utils_2keys_8h.html',1,'(Global Namespace)'],['../src_2pipewire_2extensions_2session-manager_2keys_8h.html',1,'(Global Namespace)'],['../src_2pipewire_2keys_8h.html',1,'(Global Namespace)']]]
 ];
